# aj { #polarstate.aj }

`aj`



## Functions

| Name | Description |
| --- | --- |
| [prepare_event_table](#polarstate.aj.prepare_event_table) | Generate the full event table from raw ``times`` and ``reals`` data. |

### prepare_event_table { #polarstate.aj.prepare_event_table }

```python
aj.prepare_event_table(times_and_reals)
```

Generate the full event table from raw ``times`` and ``reals`` data.

#### Parameters {.doc-section .doc-section-parameters}

| Name            | Type         | Description                                                             | Default    |
|-----------------|--------------|-------------------------------------------------------------------------|------------|
| times_and_reals | pl.DataFrame | A Polars DataFrame containing at least ``times`` and ``reals`` columns. | _required_ |

#### Returns {.doc-section .doc-section-returns}

| Name   | Type         | Description                                             |
|--------|--------------|---------------------------------------------------------|
|        | pl.DataFrame | The event table with all intermediate columns computed. |